/****************************************************************************

This file is part of the QML showcase project hosted on http://gitorious.org/qmlshowcase

Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).*
All rights reserved.

Contact:  Johannes Zellner webmaster@nebulon.de

You may use this file under the terms of the BSD license as follows:

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
* Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation and its Subsidiary(-ies) nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

****************************************************************************/

import QtQuick 1.0
import Qt.labs.particles 1.0

Item {
    id: root

    property variant activeItem: button1
    signal selected(string demo)

    function activated(demo) {
        root.selected(demo)
    }

    width: 160
    height: 600

    Image {
        id: blade
        source: "./media/HomeBlade.png"
        anchors.fill: parent
        fillMode: Image.Stretch
        smooth: true

        Flickable {
            anchors.fill: parent
            contentHeight: col.height
            contentWidth: col.width
            flickableDirection: Flickable.VerticalFlick

            Particles {
                id: part
                x: root.activeItem.x+col.x+5
                y: root.activeItem.y+col.y
                height: root.activeItem.height
                source: "./media/particle1.png"
                lifeSpan: 500
                count: 20
                angle: 0
                scale: 0.5
                opacity:  0.5
                angleDeviation: 0
                velocity: 250
                velocityDeviation: 500
                z:10
            }

            Column{
                id: col
                width: 150
                x: 0
                spacing: 10
                property int activeHeight: 70
                property int activeWidth: 150

                move: Transition {
                         NumberAnimation {
                             properties: "y"
                         }
                     }

                Button {
                    id: button1
                    text: "Scaling"
                    height: root.activeItem == button1 ? col.activeHeight : 50
                    width: root.activeItem == button1 ? col.activeWidth : 150
                    onClicked: {
                        root.activeItem = button1
                        root.activated("demo1.qml")
                    }
                }
                Button {
                    id: button2
                    width: root.activeItem == button2 ? col.activeWidth : 150
                    height: root.activeItem == button2 ? col.activeHeight : 50
                    text: "Rotation"
                    onClicked: {
                        root.activeItem = button2
                        root.activated("demo2.qml")
                    }
                }

                Button {
                    id: button3
                    width: root.activeItem == button3 ? col.activeWidth : 150
                    height: root.activeItem == button3 ? col.activeHeight : 50
                    text: "Color"
                    onClicked: {
                        root.activeItem = button3
                        root.activated("demo3.qml")
                    }
                }
                Button {
                    id:button6
                    width: root.activeItem == button6 ? col.activeWidth : 150
                    height: root.activeItem == button6 ? col.activeHeight : 50
                    text: "List View"
                    onClicked: {
                        root.activeItem = button6
                        root.activated("demo6.qml")
                    }
                }
                Button {
                    id: button7
                    width: root.activeItem == button7 ? col.activeWidth : 150
                    height: root.activeItem == button7 ? col.activeHeight : 50
                    text: "Grid View"
                    onClicked: {
                        root.activeItem = button7
                        root.activated("demo7.qml")
                    }
                }
                Button {
                    id: button8
                    width: root.activeItem == button8 ? col.activeWidth : 150
                    height: root.activeItem == button8 ? col.activeHeight : 50
                    text: "Path View"
                    onClicked: {
                        root.activeItem = button8
                        root.activated("demo8.qml")
                    }
                }
//                Button {
//                    id: button10
//                    width: root.activeItem == button10 ? col.activeWidth : 150
//                    height: root.activeItem == button10 ? col.activeHeight : 50
//                    text: "Qt3D Cube"
//                    onClicked: {
//                        root.activeItem = button10
//                        root.activated("demo10.qml")
//                    }
//                }
                Button {
                    id: button11
                    width: menu.activeItem == button11 ? col.activeWidth : 150
                    height: menu.activeItem == button11 ? col.activeHeight : 50
                    text: "PinchArea"
                    onClicked: {
                        root.activeItem = button11
                        root.activated("demo11.qml")
                    }
                }
//                Button {
//                    id: button12
//                    width: menu.activeItem == button12 ? col.activeWidth : 150
//                    height: menu.activeItem == button12 ? col.activeHeight : 50
//                    text: "NativeGL"
//                    onClicked: {
//                        root.activeItem = button12
//                        root.activated("demo12.qml")
//                    }
//                }
                Button {
                    id: button13
                    width: menu.activeItem == button13 ? col.activeWidth : 150
                    height: menu.activeItem == button13 ? col.activeHeight : 50
                    text: "About"
                    onClicked: {
                        root.activeItem = button13
                        root.activated("demo13.qml")
                    }
                }
            }
        }
    }
}
