/****************************************************************************

This file is part of the QML showcase project hosted on http://gitorious.org/qmlshowcase

Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).*
All rights reserved.

Contact:  Johannes Zellner webmaster@nebulon.de

You may use this file under the terms of the BSD license as follows:

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
* Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation and its Subsidiary(-ies) nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

****************************************************************************/

import QtQuick 1.0
import GLTexture 1.0

Item {
    id: root
    anchors.fill: parent

    GLTexture {
        source: "./media/qtlogo.png"
        id: nativeGLTexture
        width: 300
        height: 300

        transform: [
            Rotation{
                id:nativeGLTextureRotX;
                origin.x: nativeGLTexture.width/2.0;
                origin.y: nativeGLTexture.height/2.0;
                axis { x:1; y:0; z:0 }
            },
            Rotation{
                id:nativeGLTextureRotZ;
                origin.x: nativeGLTexture.width/2.0;
                origin.y: nativeGLTexture.height/2.0;
                axis { x:0; y:0; z:1 }
            }
        ]
    }

    onWidthChanged:  { moveAnimation1.restart();  moveAnimation2.restart(); }

    SequentialAnimation {
        id: moveAnimation1
        running: true; loops: Animation.Infinite
        NumberAnimation { target: nativeGLTexture; property: "x"; to: (root.width - nativeGLTexture.width)/2; duration: 1600 }
        NumberAnimation { target: nativeGLTexture; property: "x"; to: 0; duration: 2400 }
    }
    SequentialAnimation {
        id: moveAnimation2
        running: true; loops: Animation.Infinite
        NumberAnimation { target: nativeGLTexture; property: "y"; to: (root.height - nativeGLTexture.height)/2; duration: 1400 }
        NumberAnimation { target: nativeGLTexture; property: "y"; to: 0; duration: 1200 }
    }

    NumberAnimation { target: nativeGLTextureRotX; property: "angle"; to: 360; duration: 4000; running: true; loops: Animation.Infinite }
    NumberAnimation { target: nativeGLTextureRotZ; property: "angle"; to: 360; duration: 4800; running: true; loops: Animation.Infinite }

}
