/****************************************************************************

This file is part of the QML showcase project hosted on http://gitorious.org/qmlshowcase

Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).*
All rights reserved.

Contact:  Johannes Zellner webmaster@nebulon.de

You may use this file under the terms of the BSD license as follows:

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
* Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation and its Subsidiary(-ies) nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

****************************************************************************/

import QtQuick 1.0
import Qt.labs.particles 1.0

Flickable {
    id: root
    anchors.fill: parent
    contentWidth: content.width < root.width ? root.width : content.width
    contentHeight: content.height < root.height ? root.height : content.height

    Flipable {
        id: content
        anchors.fill: parent
        state:  "front"
        property bool flipped: true
        property int xAxis: 1
        property int yAxis: 1
        property int angle: 180

        front: Loader {
            anchors.fill: parent
            source: "demo1.qml"

            MouseArea {
                anchors.fill: parent
                onClicked: content.flipped = !content.flipped
            }
        }


        transform: Rotation {
            id: rotation; origin.x: content.width / 2; origin.y: content.height / 2
            axis.x: content.xAxis; axis.y: content.yAxis; axis.z: 0
        }

        states: State {
            name: "back"; when: content.flipped
            PropertyChanges { target: rotation; angle: content.angle }
        }

        transitions: Transition {
            NumberAnimation { target: rotation; properties: "angle"; duration: 600 }
        }

        back: GridView {
            id: view
            model: 500
            anchors.centerIn: parent
            width: 800
            height: parent.height
            clip: false
            cellHeight: 128
            cellWidth: 128
            rotation: -90

            delegate: Component {
                Item {
                    id: delegateItem
                    width: 128
                    height: 128
                    scale: delegateMouseArea.containsMouse ? 1.5 : 1

                    Behavior on scale {
                        NumberAnimation { duration: 100 }
                    }

                    Image {
                        id: delegateImage
                        source: "media/DefaultPicture.png"
                        anchors.centerIn: parent
                        smooth: true
                        width: 100
                        height: 100
                    }

                    transform: [
                        Rotation {
                            id: plateRotation
                            angle: -90
                            axis { x: 0; y: 1; z: 0 }
                            origin.x: -200
                            origin.y: 50
                        },
                        Rotation {
                            id: plateFlip
                            angle: 0
                            axis { x: 1; y: 0; z: 0 }
                            origin.x: 50
                            origin.y: 50
                        }
                    ]

                    SequentialAnimation {
                        id: delegateItemAnim
                        PauseAnimation { duration: Math.random()*1000 }
                        NumberAnimation {
                            target: plateRotation
                            properties: "angle"
                            easing.type: Easing.OutCubic
                            from: -90
                            to: 0
                            duration: 800
                        }
                    }

                    MouseArea {
                        id: delegateMouseArea
                        hoverEnabled: true
                        anchors.fill: parent
                        onClicked: content.flipped = !content.flipped
                    }

                    Component.onCompleted: {
                        delegateItemAnim.start()
                    }
                }
            }
        }
    }
}
