/****************************************************************************

This file is part of the QML showcase project hosted on http://gitorious.org/qmlshowcase

Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).*
All rights reserved.

Contact:  Johannes Zellner webmaster@nebulon.de

You may use this file under the terms of the BSD license as follows:

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
* Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation and its Subsidiary(-ies) nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

****************************************************************************/

import QtQuick 1.0

Item {
    id: root
    anchors.fill: parent

    PathView {
        id: view
        model: 30
        anchors.fill:parent
        clip: true
        smooth: true

        delegate: Component{
            Item {
                id: delegateItem
                width: 200
                height: 200
                smooth: true

                clip: false
                scale: PathView.scale ? PathView.scale : 1.0
                opacity : PathView.opacity ? PathView.opacity : 1
                z: PathView.z ? PathView.z : 1

                transform: [
                    Rotation {
                        axis { x: 0; y: 1; z: 0 }
                        origin { x: width/2 }
                        angle: PathView.rotationY ? PathView.rotationY : 0
                    },
                    Rotation {
                        axis { x: 0; y: 0; z: 1 }
                        origin { x: width/2; y: height/2 }
                        angle: PathView.rotationX ? PathView.rotationX : 0
                    }
                ]

                Image {
                    source: "media/DefaultPicture.png"
                    anchors.fill: parent
                    smooth: true
                    opacity: 1
                    anchors.centerIn: parent
                    transformOrigin: Item.Bottom

                    Behavior on opacity {
                        NumberAnimation {duration: 1000; easing.type: Easing.InBounce}
                    }

                    Behavior on scale {
                        NumberAnimation {}
                    }
                    id: activateImage
                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            activateImage.scale = activateImage.scale == 2 ? 1 : 2
                        }
                    }
                }

            }
        }

        preferredHighlightEnd: 0.5
        dragMargin: width

        preferredHighlightBegin: 0.5
        pathItemCount: 60
        path: Path {
            id: carousel2

            property double horizDamping: 0.85; property double horizDampingINV: 1-horizDamping
            property double vertDampingBOT: 0.7; property double vertDampingTOP: 0.1//kind of invers of vertDampingBOT

            startX: root.width
            startY: 0
            PathAttribute { name: "opacity"; value: 1 }
            PathAttribute { name: "z"; value: 1 }
            PathAttribute { name: "scale"; value: 0.3 }
            PathAttribute { name: "rotationY"; value: -90 }
            PathAttribute { name: "rotationX"; value: 0 }

            PathQuad{
                controlX: root.width*carousel2.horizDampingINV; controlY: root.height*carousel2.vertDampingTOP
                x:         root.width*carousel2.horizDampingINV; y: root.height/2.0*carousel2.vertDampingBOT }
            PathAttribute { name: "z"; value: 5 }
            PathAttribute { name: "scale"; value: 1.0 }
            PathAttribute { name: "rotationX"; value: 0 }

            PathQuad {
                controlX: root.width*carousel2.horizDampingINV; controlY: root.height*carousel2.vertDampingBOT
                x: root.width/2.0;                            y: root.height*carousel2.vertDampingBOT }
            PathAttribute { name: "z"; value: 10 }
            PathAttribute { name: "opacity"; value: 1 }
            PathAttribute { name: "scale"; value: 1.2 }
            PathAttribute { name: "rotationY"; value: 0 }
            PathAttribute { name: "rotationX"; value: 0 }

            PathLine { x: root.width; y: root.height*carousel2.vertDampingBOT }
            PathAttribute { name: "opacity"; value: 0 }
            PathAttribute { name: "z"; value: 0 }
            PathAttribute { name: "scale"; value: 0.1 }
            PathAttribute { name: "rotationY"; value: 0 }
            PathAttribute { name: "rotationX"; value: 0 }
        }

    }
}
